==> haskell-integer-conversion-0.1.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-integer-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 integer-conversion
version:              0.1.1
visibility:           public
id:                   integer-conversion-0.1.1-CkXU6U7YwsOHapoPBUWpMO
key:                  integer-conversion-0.1.1-CkXU6U7YwsOHapoPBUWpMO
license:              BSD-3-Clause
copyright:            (c) 2023 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/integer-conversion
synopsis:             Conversion from strings to Integer
description:
    The naive @foldl'\'' (\acc d -> acc * 10 + d) 0@ is expensive (quadratic!) for large @Integer@s.
    This package provides sub-quadratic implementation.

category:             Data
abi:                  8b368aed479b5d1c9340edbb8bce7773
exposed:              True
exposed-modules:      Data.Integer.Conversion
import-dirs:          /usr/lib/ghc-9.4.8/site-local/integer-conversion-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/integer-conversion-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/integer-conversion-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-integer-conversion
hs-libraries:         HSinteger-conversion-0.1.1-CkXU6U7YwsOHapoPBUWpMO
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    primitive-0.9.1.0-IHF3DoB9Qq2KNGfApZUSXg text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-integer-conversion/html/integer-conversion.haddock

haddock-html:         /usr/share/doc/haskell-integer-conversion/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-integer-conversion-0.1.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-integer-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 integer-conversion
version:              0.1.1
visibility:           public
id:                   integer-conversion-0.1.1-B8QwfubpnVJFP68Z8JrMjp
key:                  integer-conversion-0.1.1-B8QwfubpnVJFP68Z8JrMjp
license:              BSD-3-Clause
copyright:            (c) 2023 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/integer-conversion
synopsis:             Conversion from strings to Integer
description:
    The naive @foldl'\'' (\acc d -> acc * 10 + d) 0@ is expensive (quadratic!) for large @Integer@s.
    This package provides sub-quadratic implementation.

category:             Data
abi:                  1bd64fa987d8d65e7105448c6a5f658e
exposed:              True
exposed-modules:      Data.Integer.Conversion
import-dirs:          /usr/lib/ghc-9.4.8/site-local/integer-conversion-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/integer-conversion-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/integer-conversion-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-integer-conversion
hs-libraries:         HSinteger-conversion-0.1.1-B8QwfubpnVJFP68Z8JrMjp
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    primitive-0.9.1.0-GChnkqMWBe7B15Z0K3IGlf text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-integer-conversion/html/integer-conversion.haddock

haddock-html:         /usr/share/doc/haskell-integer-conversion/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
